@@ -1,3 +1,4 @@
+import datetime
 from typing import Optional, Union, List
 from uuid import UUID
 
@@ -25,10 +26,12 @@ class PlusMembership(Social):
             return None
 
     @property
-    def date(self):
-        """Returns the Membership's date in form yyyy/M"""
+    def date(self) -> Optional[datetime.datetime]:
+        """Returns the Membership's date"""
         try:
-            return self.handle.partition('/')[2]
+            # in form yyyy/M
+            parts = self.handle.split('/')
+            return datetime.datetime(year=int(parts[1]), month=int(parts[2]), day=1)
         except ValueError:
             return None
 
@@ -37,3 +40,6 @@ class PlusMembership(Social):
         assert isinstance(obj, dict)
         social = Social._from_dict(obj, PLUS_BASE_ADDRESS)
         return PlusMembership(social.handle, social.sources)
+
+    def __str__(self):
+        return f"+{self.level} ({self.date})" if self.level else f"Lost plus membership ({self.date})"
